=======
History
=======

**unreleased**
**v1.0.2**

v1.0.1 (2019-10-27)
-------------------

* Check if the browser has been started on travis
* Aadded chromedriver installation on travis
* Removed unused imports and variables and conformed to the PEP 8 style guide
* Added installation of codecov in travis
* Removed setuptools-changelog package, use only bump2version to change history
* Fixed phony and added other commands in makefile
* Changed python to python3 in makefile
* Added chrome browser in travis
* Updated features in README.rst
* Removed unused module terminaltables
* Misc: small fix or general refactoring

1.0.0 (2019-09-15)
------------------

* First release on PyPI.
